# Python demos

- [dp_check_1d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_check_1d.py)

- [dp_check_2d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_check_2d.py)

- [dp_check_3d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_check_3d.py)

- [dp_fullcheck_1d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_fullcheck_1d.py)

- [dp_fullcheck_2d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_fullcheck_2d.py)
